% This is an example of how to modify the style of your
% thesis.  Check the guidelines for your school/university
% on the required format for a PhD thesis.

% Instructions for use:


% some basic stuff (so you don't have to chase through the file looking for this):

\newcommand{\CHAPTER}{CHAPTER } % this formats the titles of your chapters
\newcommand{\TOC}{TABLE OF CONTENTS } % this formats the titles of your table of contents
\newcommand{\LOF}{LIST OF FIGURES } % this formats the titles of your
\newcommand{\LOT}{LIST OF TABLES} % this formats the titles of your


% The one thing that needs fixing here is the final periods 
% after the numbering in the TOC, LOF, and LOT.  See the
% final remarks of the sample for a little more information about this.

% ---------------------------------------------------------------------------------------------------

% First identify the class:

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{UOthesis}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}
\ProcessOptions
\LoadClass{report}

% ---------------------------------- various options -------------------------------------------

% Make the captions in your floats of the form:
%	for example: to have  Fig. 1  instead of:   Figure 1

	\renewcommand{\figurename}{Figure }
	\renewcommand{\tablename}{Table }

% ---------------- Redefining the \section, \subsection, etc. commands ----------------------

\renewcommand{\section}{\@startsection
	{section}%                   % the name
	{1}%                         % the level
	{0mm}%                       % the indent
	{-\baselineskip}%            % the before skip
	{0.5\baselineskip}%          % the after skip
	{\normalfont\bf}} % the style

\renewcommand{\subsection}{\@startsection
	{subsection}%                   % the name
	{2}%                         % the level
	{0mm}%                       % the indent
	{-\baselineskip}%            % the before skip
	{0.1\baselineskip}%          % the after skip
	{\normalfont\it}} % the style

\renewcommand{\subsubsection}{\@startsection
	{subsubsection}%                   % the name
	{3}%                         % the level
	{0mm}%                       % the indent
	{-\baselineskip}%            % the before skip
	{0.1\baselineskip}%          % the after skip
	{\normalfont\it}} % the style




% ---------------------------------- defining the chapter heading styles ------------------------------------------

% Numbered chapter heading style:
\def\thechapter{\Roman{chapter}} % sets chapter numbering style 
							% (Yes, it's ugly, but we can't help it if
							% this is what the grad school wants.)

\renewcommand{\@makechapterhead}[1]{%
	  \vspace*{.6in}%			% this sets vertical space before chapter title
	  {
%	    \ifnum \c@secnumdepth >\m@ne		% not sure what this is
	 \centerline{ \CHAPTER \space \thechapter}    % sets style for word "Chapter" followed by number
	\par\nobreak
	\vspace{.4in}			% vertical space between Chapter # and Chapter Title
%	    \fi								% this 
%	\interlinepenalty\@M					% and this are part of the mystery several lines up
	\scshape 	\centerline{#1}                            % sets style of chapter title
%	\par	  
	\vspace{.4in}			% vertical space below chapter title
	  }}

% Unnumbered chapter heading style; 
%		same as before except not numbered (i.e. Table of Contents etc.)
	
	\renewcommand{\@makeschapterhead}[1]{%
		  \vspace*{.6in}%
		  {
		    \scshape \centerline{#1}\par                            % chapter title
		    \vspace{.4in}%                                    % add some vertical space
		%    \hrule                                           % horizontal line
		%    \nobreak
		    \vspace{0in}
		  }}



% ---------------------- Table of contents, etc -----------------------------------------------------------
% this was taken from an old UO template, which had all sorts of stuff from UC schools, etc.  
% One thing we did was delete several \ssp commands, which (as a google search will tell you) was part of the old UC template madness.  It produced a harmless error for each chapter in typesetting.

%
% A \subsection command writes a
%       \contentsline{subsection}{TITLE}{PAGE}
% command on the .toc file, where TITLE contains the contents of the
% entry and PAGE is the page number.  If subsections are being numbered,
% then TITLE will be of the form
%       \numberline{NUM}{HEADING}
% where NUM is the number produced by \thesubsection.  Other sectioning
% commands work similarly.
%
% A \caption command in a '' environment writes
%    \contentsline{figure}{\numberline{NUM}{CAPTION}}{PAGE}
% on the .lof file, where NUM is the number produced by \thefigure and
% CAPTION is the figure caption.  It works similarly for a 'table'
% environment.
%
% The command \contentsline{NAME} expands to \l@NAME.  So, to specify
% the table of contents, we must define \l@chapter, \l@section,
% \l@subsection, ... ; to specify the list of figures, we must define
% \l@figure; and so on.  Most of these can be defined with the
% \@dottedtocline command, which works as follows.
%
% \@dottedtocline{LEVEL}{INDENT}{NUMWIDTH}{TITLE}{PAGE}
%    LEVEL    : An entry is produced only if LEVEL < or = value of
%               'tocdepth' counter.  Note, \chapter is level 0, \section
%               is level 1, etc.
%    INDENT   : The indentation from the outer left margin of the start
%               of the contents line.
%    NUMWIDTH : The width of a box in which the section number is to go,
%               if TITLE includes a \numberline command.
%


% This command uses the following three parameters, which are set
% with a \def (so em's can be used to make them depend upon the font).
%   \@pnumwidth : The width of a box in which the page number is put.
%   \@tocrmarg  : The right margin for multiple line entries.  One
%                 wants \@tocrmarg > or = \@pnumwidth
%   \@dotsep    : Separation between dots, in mu units.  Should be
%                 \def'd to a number like 2 or 1.7 (?)

\def\@pnumwidth{1.55em}
\def\@tocrmarg {2.55em}
\def\@dotsep{4.5}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% this sets the depth to which things are listed in the table of contents (Chapters =0, Sections =1, etc)
\setcounter{tocdepth}{1}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% TABLEOFCONTENTS

\def\tableofcontents{
	  \@restonecolfalse
	  \if@twocolumn\@restonecoltrue\onecolumn\fi
	  \chapter*{\centerline{\TOC}%
	      \@mkboth{}{}}%
	  {  
%		\vskip\baselineskip % this gives space between title of TOC and the TOC itself
		  \hspace{-.5em } % adjusts the position of the word "chapter"
		  			Chapter \hfill Page     
	   \@starttoc{toc}}\if@restonecol\twocolumn\fi
	    \vskip\baselineskip % not clear if this does anything ?
	  \vfill\eject}


\def\l@part#1#2{\addpenalty{-\@highpenalty}%
	   \addvspace{2.25em plus\p@}% space above part line
	   \begingroup
	   \@tempdima 3em         % width of box holding part number, used by
	     \parindent \z@ \rightskip \@pnumwidth             %% \numberline
	     \parfillskip -\@pnumwidth
	     { 
	     \leavevmode          % TeX command to enter horizontal mode.
	     #1\hfil \hbox to\@pnumwidth{\hss #2}}\par
	     \nobreak             % Never break after part entry
	    \global\@nobreaktrue                        
	    \everypar{\global\@nobreakfalse\everypar{}}
	                                               
	   \endgroup}


%  This readjusts indentation in the table of contents.
	\def\l@chapter#1#2{{ 
		 \vskip \baselineskip 
	    \@dottedtocline{0}{0em}{2.5em}{#1}{#2} \vskip \baselineskip}} 
	\def\l@spchapter#1#2{{
		\vskip \baselineskip 
	    \@dottedtocline{0}{0em}{2.5em}{#1}{#2} }}
	\def\l@section{\@dottedtocline{1}{2.5em}{3.2em}}
	\def\l@subsection{\@dottedtocline{2}{5.8em}{3.2em}}
	\def\l@subsubsection{\@dottedtocline{3}{10.0em}{4.1em}}
	\def\l@paragraph{\@dottedtocline{4}{14em}{5em}}
	\def\l@subparagraph{\@dottedtocline{5}{17em}{6em}}

	
% --------------------------- list of figures and list of tables -----------------------------	

	
% LIST OF FIGURES
%

\def\listoffigures{
  \@restonecolfalse
  \if@twocolumn\@restonecoltrue\onecolumn\fi
  \chapter*{\centerline{\LOF}
      \@mkboth{}{}}
  {   	  \hspace{-.5em} Figure \hfill Page
                      			%% previous line produces column headers in the table of contents.
     \vskip\baselineskip
   \@starttoc{lof}}\if@restonecol\twocolumn\fi
   \vskip\baselineskip
  \vfill\eject}

\def\l@figure{\@dottedtocline{1}{.1em}{2.3em}}




% LIST OF TABLES
%


\def\listoftables{
  \@restonecolfalse
  \if@twocolumn\@restonecoltrue\onecolumn\fi
  \chapter*{\centerline{\LOT}
      \@mkboth{}{}}
  {   	  \hspace{-.5em} Table \hfill Page
                      			%% previous line produces column headers in the table of contents.
     \vskip\baselineskip
   \@starttoc{lot}}\if@restonecol\twocolumn\fi
   \vskip\baselineskip
  \vfill\eject}

\def\l@table{\@dottedtocline{1}{.1em}{2.3em}}


\let\l@table\l@figure





% end of file:
\endinput
